==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/fr/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmer</strong> l\'opération',
    '<strong>Latest</strong> updates' => '<strong>Dernières</strong> mises à jour',
    '<strong>Mail</strong> summary' => 'Résumé par <strong>e-mail</strong>',
    'Account settings' => 'Paramètres du compte',
    'Actions' => 'Actions',
    'Add:' => 'Ajouter :',
    'Administration' => 'Administration',
    'All' => 'Tout',
    'Allow' => 'Autoriser',
    'An error occurred while handling your last action. (Handler not found).' => 'Une erreur s\'est produite lors de la traitement de votre dernière action. (Gestionnaire introuvable)',
    'An unexpected error occurred while loading the search result.' => 'Une erreur inattendue s\'est produite lors du chargement du résultat de la recherche.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Une erreur inattendue s\'est produite. Si cela se reproduit à nouveau, contactez un administrateur du site.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Une erreur inattendue du serveur s\'est produite. Si cela se reproduit à nouveau, contactez un administrateur du site.',
    'An unknown error occurred while uploading.' => 'Une erreur inconnue s\'est produite pendant l\'envoi de fichiers.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Une erreur inconnue s\'est produite lors du chargement de fichiers. Vérifiez les paramètres "php upload_max_filesize" et "post_max_size"',
    'Back' => 'Retour',
    'Back to dashboard' => 'Retour au fil d\'actualités',
    'Cancel' => 'Annuler',
    'Choose language:' => 'Choisir la langue :',
    'Close' => 'Fermer',
    'Collapse' => 'Réduire',
    'Confirm' => 'Confirmer',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Le contenu d\'un add-on doit être une instance de HActiveRecordContent ou HActiveRecordContentAddon.',
    'Copy to clipboard' => 'Copier vers le presse-papier',
    'Could not find content of addon!' => 'Le contenu de l\'add-on n\'a pu être trouvé.',
    'Could not find requested page.' => 'Impossible de trouver la page recherchée.',
    'Default' => 'Défaut',
    'Delete' => 'Supprimer',
    'Deny' => 'Interdire',
    'Do you really want to perform this action?' => 'Voulez-vous vraiment effectuer cette action ?',
    'Edit' => 'Éditer',
    'Error' => 'Erreur',
    'Error while running your last action (Invalid request method).' => 'Erreur lors de l\'exécution de votre dernière action (méthode de demande non valide).',
    'Error:' => 'Erreur :',
    'Expand' => 'Agrandir',
    'Export' => 'Exporter',
    'Info:' => 'Info :',
    'Invalid request method!' => 'Méthode de requête invalide.',
    'It looks like you may have taken the wrong turn.' => 'Il semble que vous n\'êtes pas au bon endroit...',
    'Language' => 'Langue',
    'Loading...' => 'Chargement...',
    'Login' => 'S\'identifier',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Se déconnecter',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Le module n\'est pas activé pour ce conteneur !',
    'My profile' => 'Mon profil',
    'New profile image' => 'Nouvelle image de profil',
    'Next' => 'Suivant',
    'No error information given.' => 'Aucune information d\'erreur fournie.',
    'Oooops...' => 'Oups...',
    'Open' => 'Ouvrir',
    'Please type at least 3 characters' => 'Veuillez saisir au moins 3 caractères',
    'Please type at least {count} characters' => 'Veuillez saisir au moins {count} caractères',
    'Powered by {name}' => 'Propulsé par {name}',
    'Profile dropdown' => 'Liste déroulante du profil',
    'Profile picture of {displayName}' => 'Photo de profil de {displayName}',
    'Save' => 'Enregistrer',
    'Saved' => 'Enregistré',
    'Search' => 'Rechercher',
    'Select Me' => 'Me choisir',
    'Show less' => 'Afficher moins',
    'Show more' => 'Afficher plus',
    'Some files could not be uploaded:' => 'Certains fichiers n\'ont pas pu être téléchargés :',
    'Text could not be copied to clipboard' => 'Le texte n\'a pas pu être copié dans le presse-papier',
    'Text has been copied to clipboard' => 'Le texte a été copié dans le presse-papier',
    'The date has to be in the past.' => 'La date doit être révolue.',
    'The file has been deleted.' => 'Le fichier a été supprimé.',
    'The requested resource could not be found.' => 'Impossible de trouver la ressource demandée.',
    'The space has been archived.' => 'Cet espace à été archivé.',
    'The space has been unarchived.' => 'Cet espace à été restauré.',
    'Time Zone' => 'Fuseau horaire',
    'Toggle comment menu' => 'Bascule du menu de commentaire',
    'Toggle panel menu' => 'Bascule du menu du panneau',
    'Toggle post menu' => 'Bascule du menu de contribution',
    'Toggle stream entry menu' => 'Bascule du menu du flux d\'activité',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Il y a des modifications non enregistrées, voulez-vous vraiment quitter cette page ?',
    'Unsubscribe' => 'Gérer les résumés / Se désabonner',
    'Upload' => 'Ajouter',
    'Upload file' => 'Envoyer un fichier',
    'You are not allowed to run this action.' => 'Vous n\'êtes pas autorisé à exécuter cette action.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Stop impersonation' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/messages/fr/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmer</strong> l\'opération',
    '<strong>Latest</strong> updates' => '<strong>Dernières</strong> mises à jour',
    '<strong>Mail</strong> summary' => 'Résumé par <strong>e-mail</strong>',
    'Actions' => 'Actions',
    'Add:' => 'Ajouter :',
    'Administration' => 'Administration',
    'All' => 'Tout',
    'Allow' => 'Autoriser',
    'Allow content from external source' => 'Authoriser le contenu de sources externes',
    'Always allow content from this provider!' => 'Toujours autoriser le contenu de ce fournisseur !',
    'An error occurred while handling your last action. (Handler not found).' => 'Une erreur s\'est produite lors de la traitement de votre dernière action. (Gestionnaire introuvable)',
    'An unexpected error occurred while loading the search result.' => 'Une erreur inattendue s\'est produite lors du chargement du résultat de la recherche.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Une erreur inattendue s\'est produite. Si cela se reproduit à nouveau, contactez un administrateur du site.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Une erreur s’est produite. Veuillez vérifier que votre fichier n’excède pas la taille maximale d’envoi de {maxUploadSize}.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Une erreur inattendue du serveur s\'est produite. Si cela se reproduit à nouveau, contactez un administrateur du site.',
    'Back' => 'Retour',
    'Back to dashboard' => 'Retour à la vue d\'ensemble',
    'Cancel' => 'Annuler',
    'Choose language:' => 'Choisir la langue :',
    'Close' => 'Fermer',
    'Collapse' => 'Réduire',
    'Confirm' => 'Confirmer',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Le contenu d\'un add-on doit être une instance de HActiveRecordContent ou HActiveRecordContentAddon.',
    'Copy to clipboard' => 'Copier vers le presse-papier',
    'Could not find content of addon!' => 'Le contenu de l\'add-on n\'a pu être trouvé.',
    'Could not find requested page.' => 'Impossible de trouver la page recherchée.',
    'Default' => 'Défaut',
    'Delete' => 'Supprimer',
    'Deny' => 'Interdire',
    'Do you really want to perform this action?' => 'Voulez-vous vraiment effectuer cette action ?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Souhaitez-vous activer le contenu de \'{urlPrefix}\' ?',
    'Edit' => 'Éditer',
    'Error' => 'Erreur',
    'Error while running your last action (Invalid request method).' => 'Erreur lors de l\'exécution de votre dernière action (méthode de demande non valide).',
    'Error:' => 'Erreur :',
    'Expand' => 'Agrandir',
    'Export' => 'Exporter',
    'Info:' => 'Info :',
    'Invalid request method!' => 'Méthode de requête invalide.',
    'It looks like you may have taken the wrong turn.' => 'Il semble que vous n\'êtes pas au bon endroit...',
    'Language' => 'Langue',
    'Loading...' => 'Chargement...',
    'Login' => 'S\'identifier',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Se déconnecter',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Le module n\'est pas activé pour ce conteneur !',
    'My Profile' => 'Mon profil',
    'New profile image' => 'Nouvelle image de profil',
    'Next' => 'Suivant',
    'No error information given.' => 'Aucune information d\'erreur fournie.',
    'Oooops...' => 'Oups...',
    'Open' => 'Ouvrir',
    'Please type at least 3 characters' => 'Veuillez saisir au moins 3 caractères',
    'Please type at least {count} characters' => 'Veuillez saisir au moins {count} caractères',
    'Powered by {name}' => 'Propulsé par {name}',
    'Profile dropdown' => 'Liste déroulante du profil',
    'Profile picture of {displayName}' => 'Photo de profil de {displayName}',
    'Save' => 'Enregistrer',
    'Saved' => 'Enregistré',
    'Search' => 'Rechercher',
    'Search...' => 'Rechercher...',
    'Select Me' => 'Me choisir',
    'Settings' => 'Réglages',
    'Show less' => 'Afficher moins',
    'Show more' => 'Afficher plus',
    'Some files could not be uploaded:' => 'Certains fichiers n\'ont pas pu être téléchargés :',
    'Stop impersonation' => 'Reprendre mon identité',
    'Text could not be copied to clipboard' => 'Le texte n\'a pas pu être copié dans le presse-papier',
    'Text has been copied to clipboard' => 'Le texte a été copié dans le presse-papier',
    'The date has to be in the past.' => 'La date doit être révolue.',
    'The file has been deleted.' => 'Le fichier a été supprimé.',
    'The requested resource could not be found.' => 'Impossible de trouver la ressource demandée.',
    'The space has been archived.' => 'Cet espace à été archivé.',
    'The space has been unarchived.' => 'Cet espace à été restauré.',
    'Time Zone' => 'Fuseau horaire',
    'Toggle comment menu' => 'Bascule du menu de commentaire',
    'Toggle panel menu' => 'Bascule du menu du panneau',
    'Toggle post menu' => 'Bascule du menu de contribution',
    'Toggle stream entry menu' => 'Bascule du menu du flux d\'activité',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Il y a des modifications non enregistrées, voulez-vous vraiment quitter cette page ?',
    'Unsubscribe' => 'Gérer les résumés / Se désabonner',
    'Upload' => 'Ajouter',
    'Upload file' => 'Envoyer un fichier',
    'You are not allowed to run this action.' => 'Vous n\'êtes pas autorisé à exécuter cette action.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'vérifiez vos réglages php "upload_max_filesize" et "post_max_size".',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
